Crate miden_note_codec_macros

Crate miden_note_codec_macros 

Procedural macros for author-side note codec components.

Macros

export_codecs
Exports all codecs marked earlier in the crate through the miden:note-codec component world.
from_package
Generates host-profile note types from one exact Miden package path.
from_project
Generates host-profile note types from the package built by a Miden project.

Attribute Macros

note_codec
Marks an [miden_note_codec::AuthorTypeCodec] implementation for component export.