from_package!() { /* proc-macro */ }Expand description
Generates host-profile note types from one exact Miden package path.
A relative path is resolved against CARGO_MANIFEST_DIR.
from_package!() { /* proc-macro */ }Generates host-profile note types from one exact Miden package path.
A relative path is resolved against CARGO_MANIFEST_DIR.