from_project

Macro from_project 

from_project!() { /* proc-macro */ }
Generates host-profile note types from the package built by a Miden project.

The project path is relative to CARGO_MANIFEST_DIR. Build the note project with cargo miden build before compiling the codec crate.